import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  scaleTime,
  scaleOrdinal,
  extent,
  max,
  format,
  timeFormat,
  group
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = {
  top: 20,
  right: 30,
  bottom: 65,
  left: 90,
};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const xAxisLabelOffset = 50;
const yAxisLabelOffset = 55;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xValue = (d) => d.Month;
  const xAxisLabel = 'Month';
 
  const yValue = (d) => d.DonValue;
  const yAxisLabel = 'Proportions';

  const xAxisTickFormat = timeFormat('%B');
  
  const numberFormat = (d) =>
    format('.2s')(d)
  		.replace(/^/, '% ')
  		.replace(' ', '');
  
  

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0]);
  
  const colorScale = scaleOrdinal()
  .domain(['Covid', 'Other'])
  .range(['#c11d1d', '#eae600']);

  return (
    <svg width={width} height={height}>
      <g
        className="tick"
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          tickFormat={xAxisTickFormat}
          xScale={xScale}
          innerHeight={innerHeight}
          tickOffset={7}
        />
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickOffset={-5}
          axisFormat={numberFormat}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          textAnchor="middle"
          y={innerHeight + xAxisLabelOffset}
        >
          {xAxisLabel}
        </text>
        <text
          transform={`rotate(-90) translate(${
            -innerHeight / 2
          }, ${-yAxisLabelOffset})`}
          className="axis-label"
          text-anchor="middle"
        >
          {yAxisLabel}
        </text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={6}
          colorScale={colorScale}
          innerHeight={innerHeight}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
